class Plattform extends PhysicsObject {
  
  private PVector vRange = new PVector(0,width);
  private PVector hRange = new PVector(0,height);
  
  private PVector originalSize;
  
  private int comboTime = 15000;
  private int lastCombo = millis()-comboTime;
  private boolean isLarge = false;
  
  Plattform () {
    super(10,10, 10, 0,0, 0,0);
    originalSize = new PVector(10,10);
  }
  
  Plattform (float px, float py, float pw, float ph, float speed) {
    super(pw,ph, speed, px,py, 0,0);
    originalSize = new PVector(pw,ph);
  }
  
  protected void doubleSize() {
    if (this.getDim().x > this.getDim().y) {
      this.setDimX(this.getDim().x * 2);
    } else {
      this.setDimY(this.getDim().y * 2);
    }
  }
  protected void resetSize () {
    isLarge = false;
    this.setDim(originalSize.x, originalSize.y);
  }
  
  protected void triggerCombo () {
    if(!isLarge && lastCombo + comboTime > millis()) {
      doubleSize();
      isLarge = true;
    } else {
      lastCombo = millis();
    }
  }
  protected void resetCombo () {
    if (isLarge) {
      resetSize();
      isLarge = false;
      lastCombo = 0;
    }
  }
  protected void display () {
    rect(this.getPos().x-this.getDim().x/2, this.getPos().y-this.getDim().y/2, this.getDim().x, this.getDim().y);
  }
  
  protected void moveX (float dx) {
    this.setX(this.getPos().x + constrain(dx - this.getPos().x, -this.getSpeed(), this.getSpeed()));
  }
  
  protected void moveUp () {
    this.setY(this.getPos().y-this.getSpeed());
  }
  protected void moveDown () {
    this.setY(this.getPos().y+this.getSpeed());
  }  
  protected void moveRight () {
    this.setX(this.getPos().x+this.getSpeed());
  }
  protected void moveLeft () {
    this.setX(this.getPos().x-this.getSpeed());
  }
  
  protected void step () {
    if (this.getPos().x - this.getDim().x / 2 < vRange.x) {
      this.setX(vRange.x + this.getDim().x / 2);
    } else if (this.getPos().x + this.getDim().x / 2 > vRange.y) {
      this.setX(vRange.y - this.getDim().x / 2);
    } else if (this.getPos().y - this.getDim().y / 2 < hRange.x) {
      this.setY(hRange.x + this.getDim().y / 2);
    } else if (this.getPos().y + this.getDim().y / 2 > hRange.y) {
      this.setY(hRange.y - this.getDim().y / 2);
    }
  }
  
  protected void setRange (PVector newVRange, PVector newHRange) {
    vRange = newVRange;
    hRange = newHRange;
  }
  protected void setVRange (PVector newVRange) {
    vRange = newVRange;
  }
  protected void setHRange (PVector newHRange) {
    hRange = newHRange;
  }

}
